=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com>`_.

0.5.7
------

Added
+++++
- Return standard errors on fit parameters.

0.5.6
------

Fixed
+++++
- Fixed bug with ``orderlegend`` in ``plotGrid``.

0.5.5
------

Fixed
+++++
- Only import ``dmslogo`` as needed.

0.5.4
-----

Fixed
+++++
- Fixed reading of Excel ``*.xlsx`` files.

0.5.3
-----

Fixed
+++++
- Better fitting of difficult curves by trying multiple optimization methods.

0.5.2
------

Fixed
+++++
- Better error message if virus or serum is `NaN`.

0.5.1
-----

Fixed
++++++
- `CurveFits` now works if `viruses` or `sera` are categorical.

0.5.0
------

Added
++++++
- Added `CurveFits.plotViruses` method.

0.4.2
-----

Fixed
++++++
- Bug fix in ylabel plotting.

0.4.1
------

Fixed
+++++
- Better selection of initial fit parameters when `infectivity_or_neutralized` is 'neutralized'.

0.4.0
------

Added
+++++
- `infectivity_or_neutralized` option to allow fitting of fraction neutralized as well as fraction infectivity.

Fixed
+++++
- `scipy` deprecation warnings.

0.3.1
------

Fixed
++++++
- Fixed bug when IC50 is at lower bound.

0.3.0
-----

Added
+++++
- Ability to draw vertical lines on neutralization curves (`vlines` option to `CurveFits.plotGrid` and `CurveFits.plotSera`).

0.2.5
-----

Fixed
+++++
- Better fit curves that never reach IC50.

0.2.4
-------

Fixed
+++++++
- Fix bug in ymax on some plots generated by `CurveFits`.

0.2.3
-------

Fixed
++++++++
- Fix bug in `CurveFits.plotGrid` when plotting just wildtype.

0.2.2
---------

Added
+++++++
- `ignore_serum_virus` to `CurveFits.plotSera`.

- Added options to `CurveFits.plotGrid` to **not** share x- and y-axis, and to allow different labels.

0.2.1
-------

Added
++++++
- Custom titles for `CurveFits.plotSera`.

0.2.0
-----------

Added
++++++
- Allow exclusion of specific dilutions from *RachelStyle2019* neutralization assays.

- More / better coloring options for `CurveFits.plotSera`.

- Allow more precise sizing of `CurveFits` plots.

Changed
++++++++
- Smaller tick mark sizes.

0.1.0
---------------------------
Initial release

